summaryrefslogtreecommitdiffstats
path: root/package/systemd/systemd-openslx.patch
blob: 890cfda374f284c263ddb8cdcf3cf66b025dff39 (plain) (blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
diff -wur systemd-185/src/core/main.c systemd-185.openslx/src/core/main.c
--- systemd-185/src/core/main.c	2012-05-31 11:48:49.574023370 +0200
+++ systemd-185.openslx/src/core/main.c	2012-06-25 18:42:04.918373999 +0200
@@ -177,7 +177,7 @@
                         else if ((r = make_stdio(fd)) < 0)
                                 log_error("Failed to duplicate terminal fd: %s", strerror(-r));
 
-                        execl("/bin/sh", "/bin/sh", NULL);
+                        execl("/openslx/bin/sh", "/openslx/bin/sh", NULL);
 
                         log_error("execl() failed: %s", strerror(errno));
                         _exit(1);
@@ -1774,10 +1774,10 @@
                 if (errno == ENOENT) {
                         log_warning("No /sbin/init, trying fallback");
 
-                        args[0] = "/bin/sh";
+                        args[0] = "/openslx/bin/sh";
                         args[1] = NULL;
                         execv(args[0], (char* const*) args);
-                        log_error("Failed to execute /bin/sh, giving up: %m");
+                        log_error("Failed to execute /openslx/bin/sh, giving up: %m");
                 } else
                         log_warning("Failed to execute /sbin/init, giving up: %m");
         }
diff -wur systemd-185/src/core/shutdown.c systemd-185.openslx/src/core/shutdown.c
--- systemd-185/src/core/shutdown.c	2012-05-31 12:39:40.502669670 +0200
+++ systemd-185.openslx/src/core/shutdown.c	2012-06-25 20:06:53.928343597 +0200
@@ -477,7 +477,7 @@
                         log_warning("kexec failed. Falling back to normal reboot.");
                 } else {
                         /* Child */
-                        const char *args[3] = { "/sbin/kexec", "-e", NULL };
+                        const char *args[3] = { "/openslx/sbin/kexec", "-e", NULL };
                         execv(args[0], (char * const *) args);
                         return EXIT_FAILURE;
                 }
diff -wur systemd-185/src/core/swap.c systemd-185.openslx/src/core/swap.c
--- systemd-185/src/core/swap.c	2012-05-25 03:14:20.223928784 +0200
+++ systemd-185.openslx/src/core/swap.c	2012-06-25 20:07:27.415010065 +0200
@@ -712,7 +712,7 @@
 
                 r = exec_command_set(
                                 s->control_command,
-                                "/sbin/swapon",
+                                "/openslx/sbin/swapon",
                                 "-p",
                                 p,
                                 s->what,
@@ -720,7 +720,7 @@
         } else
                 r = exec_command_set(
                                 s->control_command,
-                                "/sbin/swapon",
+                                "/openslx/sbin/swapon",
                                 s->what,
                                 NULL);
 
@@ -751,7 +751,7 @@
 
         if ((r = exec_command_set(
                              s->control_command,
-                             "/sbin/swapoff",
+                             "/openslx/sbin/swapoff",
                              s->what,
                              NULL)) < 0)
                 goto fail;
diff -wur systemd-185/src/core/switch-root.c systemd-185.openslx/src/core/switch-root.c
--- systemd-185/src/core/switch-root.c	2012-05-22 16:54:33.751007201 +0200
+++ systemd-185.openslx/src/core/switch-root.c	2012-06-25 19:45:48.695017824 +0200
@@ -29,6 +29,7 @@
 
 #include "util.h"
 #include "path-util.h"
+#include "missing.h"
 #include "switch-root.h"
 
 int switch_root(const char *new_root) {
diff -wur systemd-185/src/hostname/org.freedesktop.hostname1.service systemd-185.openslx/src/hostname/org.freedesktop.hostname1.service
--- systemd-185/src/hostname/org.freedesktop.hostname1.service	2012-04-12 01:04:30.618222912 +0200
+++ systemd-185.openslx/src/hostname/org.freedesktop.hostname1.service	2012-06-25 18:44:57.398372969 +0200
@@ -7,6 +7,6 @@
 
 [D-BUS Service]
 Name=org.freedesktop.hostname1
-Exec=/bin/false
+Exec=/openslx/bin/false
 User=root
 SystemdService=dbus-org.freedesktop.hostname1.service
diff -wur systemd-185/src/journal/cat.c systemd-185.openslx/src/journal/cat.c
--- systemd-185/src/journal/cat.c	2012-04-12 01:04:30.618222912 +0200
+++ systemd-185.openslx/src/journal/cat.c	2012-06-25 18:38:27.781708630 +0200
@@ -159,7 +159,7 @@
         fd = -1;
 
         if (argc <= optind)
-                execl("/bin/cat", "/bin/cat", NULL);
+                execl("/openslx/bin/cat", "/openslx/bin/cat", NULL);
         else
                 execvp(argv[optind], argv + optind);
 
diff -wur systemd-185/src/journal/journal-file.c systemd-185.openslx/src/journal/journal-file.c
--- systemd-185/src/journal/journal-file.c	2012-05-22 02:04:04.891877266 +0200
+++ systemd-185.openslx/src/journal/journal-file.c	2012-06-25 19:38:51.481686983 +0200
@@ -230,12 +230,14 @@
                 }
         }
 
+#ifndef __UCLIBC__
         /* Note that the glibc fallocate() fallback is very
            inefficient, hence we try to minimize the allocation area
            as we can. */
         r = posix_fallocate(f->fd, old_size, new_size - old_size);
         if (r != 0)
                 return -r;
+#endif
 
         if (fstat(f->fd, &f->last_stat) < 0)
                 return -errno;
diff -wur systemd-185/src/locale/org.freedesktop.locale1.service systemd-185.openslx/src/locale/org.freedesktop.locale1.service
--- systemd-185/src/locale/org.freedesktop.locale1.service	2012-04-12 01:04:30.621222912 +0200
+++ systemd-185.openslx/src/locale/org.freedesktop.locale1.service	2012-06-25 18:38:49.188375171 +0200
@@ -7,6 +7,6 @@
 
 [D-BUS Service]
 Name=org.freedesktop.locale1
-Exec=/bin/false
+Exec=/openslx/bin/false
 User=root
 SystemdService=dbus-org.freedesktop.locale1.service
diff -wur systemd-185/src/login/org.freedesktop.login1.service systemd-185.openslx/src/login/org.freedesktop.login1.service
--- systemd-185/src/login/org.freedesktop.login1.service	2012-04-12 01:04:30.623222912 +0200
+++ systemd-185.openslx/src/login/org.freedesktop.login1.service	2012-06-25 18:45:24.981706138 +0200
@@ -7,6 +7,6 @@
 
 [D-BUS Service]
 Name=org.freedesktop.login1
-Exec=/bin/false
+Exec=/openslx/bin/false
 User=root
 SystemdService=dbus-org.freedesktop.login1.service
diff -wur systemd-185/src/nspawn/nspawn.c systemd-185.openslx/src/nspawn/nspawn.c
--- systemd-185/src/nspawn/nspawn.c	2012-05-31 20:22:14.262509254 +0200
+++ systemd-185.openslx/src/nspawn/nspawn.c	2012-06-25 18:44:18.438373202 +0200
@@ -1099,7 +1099,7 @@
                         execvpe(argv[optind], argv + optind, (char**) envp);
                 else {
                         chdir(home ? home : "/root");
-                        execle("/bin/bash", "-bash", NULL, (char**) envp);
+                        execle("/openslx/bin/bash", "-bash", NULL, (char**) envp);
                 }
 
                 log_error("execv() failed: %m");
diff -wur systemd-185/src/remount-fs/remount-fs.c systemd-185.openslx/src/remount-fs/remount-fs.c
--- systemd-185/src/remount-fs/remount-fs.c	2012-05-08 01:57:17.740095802 +0200
+++ systemd-185.openslx/src/remount-fs/remount-fs.c	2012-06-25 18:37:34.325042284 +0200
@@ -97,15 +97,15 @@
                         const char *arguments[5];
                         /* Child */
 
-                        arguments[0] = "/bin/mount";
+                        arguments[0] = "/openslx/bin/mount";
                         arguments[1] = me->mnt_dir;
                         arguments[2] = "-o";
                         arguments[3] = "remount";
                         arguments[4] = NULL;
 
-                        execv("/bin/mount", (char **) arguments);
+                        execv("/openslx/bin/mount", (char **) arguments);
 
-                        log_error("Failed to execute /bin/mount: %m");
+                        log_error("Failed to execute /openslx/bin/mount: %m");
                         _exit(EXIT_FAILURE);
                 }
 
@@ -146,9 +146,9 @@
                 if (s) {
                         if (!is_clean_exit(si.si_code, si.si_status)) {
                                 if (si.si_code == CLD_EXITED)
-                                        log_error("/bin/mount for %s exited with exit status %i.", s, si.si_status);
+                                        log_error("/openslx/bin/mount for %s exited with exit status %i.", s, si.si_status);
                                 else
-                                        log_error("/bin/mount for %s terminated by signal %s.", s, signal_to_string(si.si_status));
+                                        log_error("/openslx/bin/mount for %s terminated by signal %s.", s, signal_to_string(si.si_status));
 
                                 ret = EXIT_FAILURE;
                         }
diff -wur systemd-185/src/shared/macro.h systemd-185.openslx/src/shared/macro.h
--- systemd-185/src/shared/macro.h	2012-05-08 01:57:17.656095804 +0200
+++ systemd-185.openslx/src/shared/macro.h	2012-06-25 19:39:41.575020016 +0200
@@ -28,6 +28,23 @@
 #include <sys/uio.h>
 #include <inttypes.h>
 
+#ifdef __UCLIBC__
+/* uclibc does not implement mkostemp GNU extension */
+#define mkostemp(x,y) mkstemp(x)
+/* uclibc does not implement execvpe GNU extension */
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
+#endif
+#include <unistd.h>
+static inline int execvpe(const char *file, char *const argv[],
+                          char *const envp[])
+{
+        environ = (char **)envp;
+        return execvp(file, argv);
+}
+#endif
+
+
 #define _printf_attr_(a,b) __attribute__ ((format (printf, a, b)))
 #define _sentinel_ __attribute__ ((sentinel))
 #define _noreturn_ __attribute__((noreturn))
diff -wur systemd-185/src/udev/keymap/check-keymaps.sh systemd-185.openslx/src/udev/keymap/check-keymaps.sh
--- systemd-185/src/udev/keymap/check-keymaps.sh	2012-04-13 15:38:11.006520858 +0200
+++ systemd-185.openslx/src/udev/keymap/check-keymaps.sh	2012-06-25 20:05:19.998344159 +0200
@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/openslx/bin/bash
 
 # check that all key names in keymaps/* are known in <linux/input.h>
 # and that all key maps listed in the rules are valid and present in
diff -wur systemd-185/src/udev/keymap/findkeyboards systemd-185.openslx/src/udev/keymap/findkeyboards
--- systemd-185/src/udev/keymap/findkeyboards	2012-04-04 00:44:27.744055165 +0200
+++ systemd-185.openslx/src/udev/keymap/findkeyboards	2012-06-25 20:06:13.815010504 +0200
@@ -1,4 +1,4 @@
-#!/bin/sh -e
+#!/openslx/bin/sh -e
 # Find "real" keyboard devices and print their device path.
 # Author: Martin Pitt <martin.pitt@ubuntu.com>
 #
diff -wur systemd-185/src/udev/keymap/keyboard-force-release.sh systemd-185.openslx/src/udev/keymap/keyboard-force-release.sh
--- systemd-185/src/udev/keymap/keyboard-force-release.sh	2012-06-04 20:16:53.647460647 +0200
+++ systemd-185.openslx/src/udev/keymap/keyboard-force-release.sh	2012-06-25 20:05:30.345010763 +0200
@@ -1,4 +1,4 @@
-#!/bin/sh -e
+#!/openslx/bin/sh -e
 # read list of scancodes, convert hex to decimal and
 # append to the atkbd force_release sysfs attribute
 # $1 sysfs devpath for serioX
diff -wur systemd-185/src/udev/keymap/keyboard-force-release.sh.in systemd-185.openslx/src/udev/keymap/keyboard-force-release.sh.in
--- systemd-185/src/udev/keymap/keyboard-force-release.sh.in	2012-06-04 12:43:31.119305508 +0200
+++ systemd-185.openslx/src/udev/keymap/keyboard-force-release.sh.in	2012-06-25 20:05:42.231677359 +0200
@@ -1,4 +1,4 @@
-#!/bin/sh -e
+#!/openslx/bin/sh -e
 # read list of scancodes, convert hex to decimal and
 # append to the atkbd force_release sysfs attribute
 # $1 sysfs devpath for serioX
diff -wur systemd-185/units/console-getty.service.m4.in systemd-185.openslx/units/console-getty.service.m4.in
--- systemd-185/units/console-getty.service.m4.in	2012-05-31 20:23:02.825548823 +0200
+++ systemd-185.openslx/units/console-getty.service.m4.in	2012-06-25 20:02:25.391678536 +0200
@@ -30,7 +30,7 @@
 Before=getty.target
 
 [Service]
-ExecStart=-/sbin/agetty --noclear -s console 115200,38400,9600
+ExecStart=-/openslx/sbin/agetty --noclear -s console 115200,38400,9600
 Type=idle
 Restart=always
 RestartSec=0
diff -wur systemd-185/units/console-shell.service.m4.in systemd-185.openslx/units/console-shell.service.m4.in
--- systemd-185/units/console-shell.service.m4.in	2012-04-24 14:49:10.162332686 +0200
+++ systemd-185.openslx/units/console-shell.service.m4.in	2012-06-25 20:02:25.391678536 +0200
@@ -31,7 +31,7 @@
 [Service]
 Environment=HOME=/root
 WorkingDirectory=/root
-ExecStart=-/sbin/sulogin
+ExecStart=-/openslx/sbin/sulogin
 ExecStopPost=-@SYSTEMCTL@ poweroff
 Type=idle
 StandardInput=tty-force
diff -wur systemd-185/units/emergency.service systemd-185.openslx/units/emergency.service
--- systemd-185/units/emergency.service	2012-06-04 20:17:02.143457560 +0200
+++ systemd-185.openslx/units/emergency.service	2012-06-25 20:02:25.388345203 +0200
@@ -14,10 +14,10 @@
 [Service]
 Environment=HOME=/root
 WorkingDirectory=/root
-ExecStartPre=-/bin/plymouth quit
-ExecStartPre=-/bin/echo 'Welcome to emergency mode. Use "systemctl default" or ^D to enter default mode.'
-ExecStart=-/sbin/sulogin
-ExecStopPost=/usr/bin/systemctl --fail --no-block default
+ExecStartPre=-/openslx/bin/plymouth quit
+ExecStartPre=-/openslx/bin/echo 'Welcome to emergency mode. Use "systemctl default" or ^D to enter default mode.'
+ExecStart=-/openslx/sbin/sulogin
+ExecStopPost=/openslx/usr/bin/systemctl --fail --no-block default
 Type=idle
 StandardInput=tty-force
 StandardOutput=inherit
diff -wur systemd-185/units/emergency.service.in systemd-185.openslx/units/emergency.service.in
--- systemd-185/units/emergency.service.in	2012-05-21 19:23:02.768293222 +0200
+++ systemd-185.openslx/units/emergency.service.in	2012-06-25 20:02:25.391678536 +0200
@@ -14,9 +14,9 @@
 [Service]
 Environment=HOME=/root
 WorkingDirectory=/root
-ExecStartPre=-/bin/plymouth quit
-ExecStartPre=-/bin/echo 'Welcome to emergency mode. Use "systemctl default" or ^D to enter default mode.'
-ExecStart=-/sbin/sulogin
+ExecStartPre=-/openslx/bin/plymouth quit
+ExecStartPre=-/openslx/bin/echo 'Welcome to emergency mode. Use "systemctl default" or ^D to enter default mode.'
+ExecStart=-/openslx/sbin/sulogin
 ExecStopPost=@SYSTEMCTL@ --fail --no-block default
 Type=idle
 StandardInput=tty-force
diff -wur systemd-185/units/getty@.service.m4 systemd-185.openslx/units/getty@.service.m4
--- systemd-185/units/getty@.service.m4	2012-05-21 19:23:02.769293222 +0200
+++ systemd-185.openslx/units/getty@.service.m4	2012-06-25 19:31:46.471689522 +0200
@@ -41,7 +41,7 @@
 
 [Service]
 Environment=TERM=linux
-ExecStart=-/sbin/agetty %I 38400
+ExecStart=-/openslx/sbin/getty -L %I 115200 vt100
 Type=idle
 Restart=always
 RestartSec=0
diff -wur systemd-185/units/plymouth-halt.service systemd-185.openslx/units/plymouth-halt.service
--- systemd-185/units/plymouth-halt.service	2012-04-12 01:04:30.635222913 +0200
+++ systemd-185.openslx/units/plymouth-halt.service	2012-06-25 20:02:25.388345203 +0200
@@ -13,6 +13,6 @@
 ConditionKernelCommandLine=!plymouth.enable=0
 
 [Service]
-ExecStart=/sbin/plymouthd --mode=shutdown
-ExecStartPost=-/bin/plymouth --show-splash
+ExecStart=/openslx/sbin/plymouthd --mode=shutdown
+ExecStartPost=-/openslx/bin/plymouth --show-splash
 Type=forking
diff -wur systemd-185/units/plymouth-kexec.service systemd-185.openslx/units/plymouth-kexec.service
--- systemd-185/units/plymouth-kexec.service	2012-04-12 01:04:30.635222913 +0200
+++ systemd-185.openslx/units/plymouth-kexec.service	2012-06-25 20:02:25.391678536 +0200
@@ -13,6 +13,6 @@
 ConditionKernelCommandLine=!plymouth.enable=0
 
 [Service]
-ExecStart=/sbin/plymouthd --mode=shutdown
-ExecStartPost=-/bin/plymouth --show-splash
+ExecStart=/openslx/sbin/plymouthd --mode=shutdown
+ExecStartPost=-/openslx/bin/plymouth --show-splash
 Type=forking
diff -wur systemd-185/units/plymouth-poweroff.service systemd-185.openslx/units/plymouth-poweroff.service
--- systemd-185/units/plymouth-poweroff.service	2012-04-12 01:04:30.635222913 +0200
+++ systemd-185.openslx/units/plymouth-poweroff.service	2012-06-25 20:02:25.391678536 +0200
@@ -13,6 +13,6 @@
 ConditionKernelCommandLine=!plymouth.enable=0
 
 [Service]
-ExecStart=/sbin/plymouthd --mode=shutdown
-ExecStartPost=-/bin/plymouth --show-splash
+ExecStart=/openslx/sbin/plymouthd --mode=shutdown
+ExecStartPost=-/openslx/bin/plymouth --show-splash
 Type=forking
diff -wur systemd-185/units/plymouth-quit.service systemd-185.openslx/units/plymouth-quit.service
--- systemd-185/units/plymouth-quit.service	2012-05-14 14:34:12.817358222 +0200
+++ systemd-185.openslx/units/plymouth-quit.service	2012-06-25 20:02:25.391678536 +0200
@@ -10,6 +10,6 @@
 After=rc-local.service plymouth-start.service systemd-user-sessions.service
 
 [Service]
-ExecStart=-/bin/plymouth quit
+ExecStart=-/openslx/bin/plymouth quit
 Type=oneshot
 TimeoutSec=20
diff -wur systemd-185/units/plymouth-quit-wait.service systemd-185.openslx/units/plymouth-quit-wait.service
--- systemd-185/units/plymouth-quit-wait.service	2012-05-14 14:34:12.817358222 +0200
+++ systemd-185.openslx/units/plymouth-quit-wait.service	2012-06-25 20:02:25.391678536 +0200
@@ -10,6 +10,6 @@
 After=rc-local.service plymouth-start.service systemd-user-sessions.service
 
 [Service]
-ExecStart=-/bin/plymouth --wait
+ExecStart=-/openslx/bin/plymouth --wait
 Type=oneshot
 TimeoutSec=20
diff -wur systemd-185/units/plymouth-read-write.service systemd-185.openslx/units/plymouth-read-write.service
--- systemd-185/units/plymouth-read-write.service	2012-04-12 01:04:30.635222913 +0200
+++ systemd-185.openslx/units/plymouth-read-write.service	2012-06-25 20:02:25.391678536 +0200
@@ -12,5 +12,5 @@
 Before=sysinit.target
 
 [Service]
-ExecStart=-/bin/plymouth update-root-fs --read-write
+ExecStart=-/openslx/bin/plymouth update-root-fs --read-write
 Type=oneshot
diff -wur systemd-185/units/plymouth-reboot.service systemd-185.openslx/units/plymouth-reboot.service
--- systemd-185/units/plymouth-reboot.service	2012-04-12 01:04:30.635222913 +0200
+++ systemd-185.openslx/units/plymouth-reboot.service	2012-06-25 20:02:25.391678536 +0200
@@ -13,6 +13,6 @@
 ConditionKernelCommandLine=!plymouth.enable=0
 
 [Service]
-ExecStart=/sbin/plymouthd --mode=shutdown
-ExecStartPost=-/bin/plymouth --show-splash
+ExecStart=/openslx/sbin/plymouthd --mode=shutdown
+ExecStartPost=-/openslx/bin/plymouth --show-splash
 Type=forking
diff -wur systemd-185/units/plymouth-start.service systemd-185.openslx/units/plymouth-start.service
--- systemd-185/units/plymouth-start.service	2012-05-29 22:32:35.869895860 +0200
+++ systemd-185.openslx/units/plymouth-start.service	2012-06-25 20:02:25.391678536 +0200
@@ -17,6 +17,6 @@
 ConditionKernelCommandLine=!plymouth.enable=0
 
 [Service]
-ExecStart=/sbin/plymouthd --mode=boot --pid-file=/run/plymouth/pid
-ExecStartPost=-/bin/plymouth --show-splash
+ExecStart=/openslx/sbin/plymouthd --mode=boot --pid-file=/run/plymouth/pid
+ExecStartPost=-/openslx/bin/plymouth --show-splash
 Type=forking
diff -wur systemd-185/units/quotacheck.service.in systemd-185.openslx/units/quotacheck.service.in
--- systemd-185/units/quotacheck.service.in	2012-04-24 17:37:54.487812040 +0200
+++ systemd-185.openslx/units/quotacheck.service.in	2012-06-25 20:02:25.391678536 +0200
@@ -10,7 +10,7 @@
 DefaultDependencies=no
 After=systemd-readahead-collect.service systemd-readahead-replay.service systemd-remount-fs.service
 Before=local-fs.target shutdown.target
-ConditionPathExists=/sbin/quotacheck
+ConditionPathExists=/openslx/sbin/quotacheck
 
 [Service]
 Type=oneshot
diff -wur systemd-185/units/quotaon.service systemd-185.openslx/units/quotaon.service
--- systemd-185/units/quotaon.service	2012-04-12 01:04:30.636222913 +0200
+++ systemd-185.openslx/units/quotaon.service	2012-06-25 20:02:25.391678536 +0200
@@ -10,9 +10,9 @@
 DefaultDependencies=no
 After=systemd-readahead-collect.service systemd-readahead-replay.service quotacheck.service
 Before=local-fs.target shutdown.target
-ConditionPathExists=/sbin/quotaon
+ConditionPathExists=/openslx/sbin/quotaon
 
 [Service]
 Type=oneshot
 RemainAfterExit=yes
-ExecStart=/sbin/quotaon -aug
+ExecStart=/openslx/sbin/quotaon -aug
diff -wur systemd-185/units/rescue.service.m4.in systemd-185.openslx/units/rescue.service.m4.in
--- systemd-185/units/rescue.service.m4.in	2012-05-22 16:54:33.753007201 +0200
+++ systemd-185.openslx/units/rescue.service.m4.in	2012-06-25 20:02:25.395011869 +0200
@@ -15,21 +15,21 @@
 [Service]
 Environment=HOME=/root
 WorkingDirectory=/root
-ExecStartPre=-/bin/plymouth quit
-ExecStartPre=-/bin/echo -e 'Welcome to rescue mode! Type "systemctl default" or ^D to enter default mode.\\nType "journalctl" to view system logs. Type "systemctl reboot" to reboot.'
+ExecStartPre=-/openslx/bin/plymouth quit
+ExecStartPre=-/openslx/bin/echo -e 'Welcome to rescue mode! Type "systemctl default" or ^D to enter default mode.\\nType "journalctl" to view system logs. Type "systemctl reboot" to reboot.'
 m4_ifdef(`TARGET_FEDORA',
 `EnvironmentFile=/etc/sysconfig/init
-ExecStart=-/bin/bash -c "exec ${SINGLE}"',
+ExecStart=-/openslx/bin/bash -c "exec ${SINGLE}"',
 m4_ifdef(`TARGET_MANDRIVA',
 `EnvironmentFile=/etc/sysconfig/init
-ExecStart=-/bin/bash -c "exec ${SINGLE}"',
+ExecStart=-/openslx/bin/bash -c "exec ${SINGLE}"',
 m4_ifdef(`TARGET_MAGEIA',
 `EnvironmentFile=/etc/sysconfig/init
-ExecStart=-/bin/bash -c "exec ${SINGLE}"',
+ExecStart=-/openslx/bin/bash -c "exec ${SINGLE}"',
 m4_ifdef(`TARGET_MEEGO',
 `EnvironmentFile=/etc/sysconfig/init
-ExecStart=-/bin/bash -c "exec ${SINGLE}"',
-`ExecStart=-/sbin/sulogin'))))
+ExecStart=-/openslx/bin/bash -c "exec ${SINGLE}"',
+`ExecStart=-/openslx/sbin/sulogin'))))
 ExecStopPost=-@SYSTEMCTL@ --fail --no-block default
 Type=idle
 StandardInput=tty-force
diff -wur systemd-185/units/serial-getty@.service.m4 systemd-185.openslx/units/serial-getty@.service.m4
--- systemd-185/units/serial-getty@.service.m4	2012-05-21 19:23:02.773293222 +0200
+++ systemd-185.openslx/units/serial-getty@.service.m4	2012-06-25 19:32:10.101689381 +0200
@@ -37,7 +37,7 @@
 
 [Service]
 Environment=TERM=vt102
-ExecStart=-/sbin/agetty -s %I 115200,38400,9600
+ExecStart=-/openslx/sbin/getty -L %I 115200 vt100
 Type=idle
 Restart=always
 RestartSec=0
diff -wur systemd-185/units/systemd-readahead-drop.service systemd-185.openslx/units/systemd-readahead-drop.service
--- systemd-185/units/systemd-readahead-drop.service	2012-05-23 04:10:44.080608263 +0200
+++ systemd-185.openslx/units/systemd-readahead-drop.service	2012-06-25 20:02:25.391678536 +0200
@@ -11,7 +11,7 @@
 
 [Service]
 Type=oneshot
-ExecStart=/bin/rm -f /.readahead
+ExecStart=/openslx/bin/rm -f /.readahead
 
 [Install]
 WantedBy=system-update.target
diff -wur systemd-185/units/systemd-udev-settle.service systemd-185.openslx/units/systemd-udev-settle.service
--- systemd-185/units/systemd-udev-settle.service	2012-06-04 20:17:02.951457265 +0200
+++ systemd-185.openslx/units/systemd-udev-settle.service	2012-06-25 20:02:25.391678536 +0200
@@ -29,7 +29,7 @@
 Type=oneshot
 TimeoutSec=180
 RemainAfterExit=yes
-ExecStart=/usr/bin/udevadm settle
+ExecStart=/openslx/usr/bin/udevadm settle
 
 [Install]
 WantedBy=basic.target
diff -wur systemd-185/units/systemd-udev-trigger.service systemd-185.openslx/units/systemd-udev-trigger.service
--- systemd-185/units/systemd-udev-trigger.service	2012-06-04 20:17:02.933457272 +0200
+++ systemd-185.openslx/units/systemd-udev-trigger.service	2012-06-25 20:02:25.391678536 +0200
@@ -17,4 +17,4 @@
 [Service]
 Type=oneshot
 RemainAfterExit=yes
-ExecStart=/usr/bin/udevadm trigger --type=subsystems --action=add ; /usr/bin/udevadm trigger --type=devices --action=add
+ExecStart=/openslx/usr/bin/udevadm trigger --type=subsystems --action=add ; /openslx/usr/bin/udevadm trigger --type=devices --action=add
diff -wur systemd-185/src/core/mount.c systemd-185.openslx/src/core/mount.c
--- systemd-185/src/core/mount.c	2012-05-31 12:39:40.502669670 +0200
+++ systemd-185.openslx/src/core/mount.c	2012-06-25 18:39:46.518374826 +0200
@@ -79,7 +79,7 @@
                 m->exec_context.std_error = u->manager->default_std_error;
         }
 
         /* We need to make sure that /bin/mount is always called in
          * the same process group as us, so that the autofs kernel
          * side doesn't send us another mount request while we are
          * already trying to comply its last one. */
@@ -887,7 +887,7 @@
 
         if ((r = exec_command_set(
                              m->control_command,
-                             "/bin/umount",
+                             "/openslx/bin/umount",
                              m->where,
                              NULL)) < 0)
                 goto fail;
@@ -925,7 +925,7 @@
         if (m->from_fragment)
                 r = exec_command_set(
                                 m->control_command,
-                                "/bin/mount",
+                                "/openslx/bin/mount",
                                 m->parameters_fragment.what,
                                 m->where,
                                 "-t", m->parameters_fragment.fstype ? m->parameters_fragment.fstype : "auto",
@@ -981,7 +981,7 @@
 
                 r = exec_command_set(
                                 m->control_command,
-                                "/bin/mount",
+                                "/openslx/bin/mount",
                                 m->parameters_fragment.what,
                                 m->where,
                                 "-t", m->parameters_fragment.fstype ? m->parameters_fragment.fstype : "auto",
@@ -79,7 +79,7 @@
         }
 
-        /* We need to make sure that /bin/mount is always called in
+        /* We need to make sure that /openslx/bin/mount is always called in
          * the same process group as us, so that the autofs kernel
          * side doesn't send us another mount request while we are